@@ -1,8 +1,17 @@
 from collections import MutableMapping
 
-from dingus import Dingus
+from dingus import Dingus, DingusTestCase, exception_raiser, DontCare
 
 
+__all__ = [
+    'DeterministicDingus',
+    'Dingus',
+    'DingusTestCase',
+    'DingusWhitelistTestCase',
+    'DontCare',
+    'exception_raiser',
+]
+
 class NonHashingMap(MutableMapping):
     """This is a :class:`dict`\ -like object that supports unhashable keys.
 
@@ -108,6 +117,9 @@ class DingusWhitelistTestCase(object):
         for key in self.additional_mocks:
             setattr(self, key, Dingus(key))
 
+        if hasattr(self, 'run') and callable(self.run):
+            self.run()
+
     def teardown(self):
         self.module.__dict__.clear()
         self.module.__dict__.update(self.__old_module_dict)
